################## STATISTICS FOR PSYCHOLOGY PSYCH-UH 1004Q #############################################################
####################### RECITATION 5: t-test and CIs ####################################################################
################################ SOLUTIONS ##############################################################################
#########################################################################################################################
#########################################################################################################################

library(tidyverse) # open our beloved package

#The example relates to whether arachnophobia (fear of spiders) is specific to real spiders or whether pictures of spiders can evoke similar levels of anxiety. Twenty-four arachnophobes were used in all. Twelve were asked to play with a big hairy tarantula spider with big “fangs and an evil look in its eight eyes. Their subsequent anxiety was measured. The remaining 12 were shown only pictures of the same big hairy tarantula and again their anxiety was measured.

# load the csv file
spiderData <- read_csv("spider.csv")

# what is the research question? what's the IV? what's the DV? how can we formalize it mathematically?
# mean.group1 = mean.group2

# calculate means and standard error for each group using the %>% operator, the group_by() and summarize() functions... Do we remember how we do this?
spiderData.Summary <- spiderData %>% #first take the original dataset and then add the %>% operator
  group_by(Group) %>% # group by the independent variable name, and then add the %>% operation
  summarise(mean=mean(Anxiety), sampleSize = n(), var=var(Anxiety), sd=sd(Anxiety), se=sd/sqrt(sampleSize))# create a new dataset with the summarize() function, with mean, sample size, var, sd, and se as variables
  
# let's plot our means!
ggplot(spiderData.Summary, aes(x=Group, y=mean))+ # define the dataset you want to plot the data from, and the aesthetics
  geom_col() + # define the kind of plot you want
  geom_errorbar(aes(ymin=mean-se, ymax=mean+se), width=.3) # define the error bar skewers


# Now, what if I want to plot 95% CIs instead of SEs?
# how to we calculate CIs again? t*se OR t*sp -- We are going to use the pooled variance formula because we are assuming that the variance of the two groups is equal.

tcrit = qt(p=0.975, df=nrow(spiderData)-1) # why p=0.975?
sp = sqrt((((spiderData.Summary$var[spiderData.Summary$Group=='Picture']*(spiderData.Summary$sampleSize[spiderData.Summary$Group=='Picture']-1)) + (spiderData.Summary$var[spiderData.Summary$Group=='Real Spider']*(spiderData.Summary$sampleSize[spiderData.Summary$Group=='Real Spider']-1)))/(spiderData.Summary$sampleSize[spiderData.Summary$Group=='Picture']+spiderData.Summary$sampleSize[spiderData.Summary$Group=='Real Spider']-2)))
  
ci = tcrit*sp

# let's replot the means of our data with the CIs as error bars (instead of the SEs)... don't copy and paste, pleeeeeeaseeee! :)
ggplot(spiderData.Summary, aes(x=Group, y=mean))+ # define the dataset you want to plot the data from, and the aesthetics
  geom_col() + # define the kind of plot you want
  geom_errorbar(aes(ymin=mean-ci, ymax=mean+ci), width=.3) # define the error bar skewers

# Let's now run a statistical test! which should we run? O one-sample or a two-sample (independent) t-test? why?

## let's calculate t manually first
t = (spiderData.Summary$mean[spiderData.Summary$Group=="Picture"]-spiderData.Summary$mean[spiderData.Summary$Group=="Real Spider"])/(sp*sqrt(1/12+1/12))
  
# once we have t, we can also retrieve the corresponding p-value, right?
pt(t, df=nrow(spiderData)-2) # this is going to be the one-tailed p-value, how to I get the two-tailed p-value?

pt(t, df=nrow(spiderData)-2)*2 # by multiplying by 2 we can the two-tailed p-value

## then we can use the t.test function to prove ourselves we grasped the calculations under the hood
t.test(Anxiety ~ Group, data=spiderData, alternative='two.sided', var.equal=TRUE) # let's look at the help and see how the function works! 

# how do we calculate the standardized effect size (Cohen's d)?
d = -(spiderData.Summary$mean[spiderData.Summary$Group=='Picture']-spiderData.Summary$mean[spiderData.Summary$Group=='Real Spider'])/sp
d.fromt = abs(t)*sqrt(2/nrow(spiderData))
  
  